using System;
using System.Data;
using System.Text;
using System.Security.Cryptography;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

public class CryptoManager
{
    public static string ComputeHash( string plainText, string hashAlgorithm, byte[] saltBytes )
    {
        if ( saltBytes == null )
        {
            int minSaltSize = 16;
            int maxSaltSize = 32;

            Random random = new Random();
            int saltSize = random.Next( minSaltSize, maxSaltSize );

            saltBytes = new byte[saltSize];

            RNGCryptoServiceProvider rng = new RNGCryptoServiceProvider();

            rng.GetNonZeroBytes( saltBytes );
        }

        byte[] plainTextBytes = Encoding.UTF8.GetBytes( plainText );
        byte[] plainTextWithSaltBytes = new byte[plainTextBytes.Length + saltBytes.Length];

        for ( int i = 0; i < plainTextBytes.Length; i++ ) plainTextWithSaltBytes[i] = plainTextBytes[i];

        for (int i = 0; i < saltBytes.Length; i++) plainTextWithSaltBytes[plainTextBytes.Length + i] = saltBytes[i];

        HashAlgorithm hash;

        if ( hashAlgorithm == null ) hashAlgorithm = "";

        switch ( hashAlgorithm.ToUpper() )
        {
            case "SHA1":
                hash = new SHA1Managed();
                break;

            case "SHA256":
                hash = new SHA256Managed();
                break;

            case "SHA384":
                hash = new SHA384Managed();
                break;

            case "SHA512":
                hash = new SHA512Managed();
                break;

            default:
                hash = new MD5CryptoServiceProvider();
                break;
        }

        byte[] hashBytes = hash.ComputeHash( plainTextWithSaltBytes );
        byte[] hashWithSaltBytes = new byte[hashBytes.Length + saltBytes.Length];

        for ( int i = 0; i < hashBytes.Length; i++ ) hashWithSaltBytes[i] = hashBytes[i];

        for ( int i = 0; i < saltBytes.Length; i++ ) hashWithSaltBytes[hashBytes.Length + i] = saltBytes[i];

        string hashValue = Convert.ToBase64String( hashWithSaltBytes );

        return hashValue;
    }

    public static bool VerifyHash( string plainText, string hashAlgorithm, string hashValue )
    {
        byte[] hashWithSaltBytes = Convert.FromBase64String(hashValue);
        int hashSizeInBits;
        int hashSizeInBytes;

        if ( hashAlgorithm == null ) hashAlgorithm = "";

        switch ( hashAlgorithm.ToUpper() )
        {
            case "SHA1":
                hashSizeInBits = 160;
                break;

            case "SHA256":
                hashSizeInBits = 256;
                break;

            case "SHA384":
                hashSizeInBits = 384;
                break;

            case "SHA512":
                hashSizeInBits = 512;
                break;

            default:
                hashSizeInBits = 128;
                break;
        }

        hashSizeInBytes = hashSizeInBits / 8;

        if ( hashWithSaltBytes.Length < hashSizeInBytes ) return false;

        byte[] saltBytes = new byte[hashWithSaltBytes.Length - hashSizeInBytes];

        for ( int i = 0; i < saltBytes.Length; i++ ) saltBytes[i] = hashWithSaltBytes[hashSizeInBytes + i];

        string expectedHashString = ComputeHash(plainText, hashAlgorithm, saltBytes);

        return ( hashValue == expectedHashString );
    }
}
