using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Web.Configuration;
using System.Configuration.Provider;

public class OdbcQueryManager
{
    protected ConnectionStringSettingsCollection connectionStringCollection;
    protected string connectionString;
    protected OdbcConnection connection;
    protected OdbcCommand command;
    protected OdbcDataReader dataReader;

	public OdbcQueryManager( string odbcConnectionStringName )
	{
        connectionStringCollection = System.Configuration.ConfigurationManager.ConnectionStrings;
        connectionString = connectionStringCollection[odbcConnectionStringName].ConnectionString;
        connection = new OdbcConnection( connectionString );
        command = null;
        dataReader = null;
	}

    public bool UserExists( string username )
    {
        command = new OdbcCommand( "SELECT * FROM alumni.osoba WHERE konto = ?", connection );

        command.Parameters.Add("@alumni.osoba.konto", OdbcType.VarChar, 20).Value = username.ToLower();

        bool exists = false;

        try
        {
            connection.Open();

            if( command.ExecuteNonQuery() > 0 ) exists = true;
        }
        catch ( OdbcException ex )
        {
            throw ex;
        }
        finally
        {
            connection.Close();
        }

        return exists;
    }

    public bool EmailExists( string email )
    {
        command = new OdbcCommand( "SELECT * FROM alumni.osoba WHERE email = ?", connection );

        command.Parameters.Add("@alumni.osoba.email", OdbcType.VarChar, 20).Value = ConvertEmail( email );

        bool exists = false;

        try
        {
            connection.Open();

            if( command.ExecuteNonQuery() > 0 ) exists = true;
        }
        catch ( OdbcException ex )
        {
            throw ex;
        }
        finally
        {
            connection.Close();
        }

        return exists;
    }

    protected string ConvertEmail( string email )
    {
        string[] emailParts = email.Split( new char[] {'@'} );

        emailParts[1] = emailParts[1].ToLower();

        return emailParts[0] + "@" + emailParts[1]; 
    }

    public OdbcDataReader RunSql(string sql)
    {
        command = new OdbcCommand(sql, connection);
        connection.Open();
        return command.ExecuteReader(CommandBehavior.CloseConnection);
    }
}
