using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

/// <summary>
/// Summary description for ProfessionQueryManager
/// </summary>
public class ProfessionQueryManager : OdbcQueryManager
{
    public ProfessionQueryManager(string odbcConnectionStringName) : base(odbcConnectionStringName) { }

    public bool InsertJob(int osoba_id, string pozicia, int odvetvie, DateTime datum_od,
                            DateTime datum_do, string nazov, string pozn, int adresa_id)
    {
        int pozicia_odvetvie_id = GetPosition_Sector_ID(pozicia, odvetvie);

        command = new OdbcCommand("INSERT INTO alumni.pracovny_pomer( osoba_id, pozicia_odvetvie_id, datum_od," +
                "datum_do, nazov_firmy, poznamka, adresa_id )" +
                " VALUES ( ?, ?, ?, ?, ?, ?, ? )", connection);

        command.Parameters.Add("@osoba_id", OdbcType.Int).Value = osoba_id;
        command.Parameters.Add("@pozicia_odvetvie_id", OdbcType.Int).Value = pozicia_odvetvie_id;
        command.Parameters.Add("@datum_od", OdbcType.Date).Value = datum_od;
        command.Parameters.Add("@datum_do", OdbcType.Date).Value = datum_do;
        command.Parameters.Add("@nazov_firmy", OdbcType.VarChar, 50).Value = nazov;
        command.Parameters.Add("@poznamka", OdbcType.Text).Value = pozn;
        command.Parameters.Add("@adresa_id", OdbcType.Int).Value = adresa_id;

        try
        {
            connection.Open();
            command.Transaction = connection.BeginTransaction();
            command.ExecuteNonQuery();
            command.Transaction.Commit();
        }
        catch (OdbcException ex)
        {
            command.Transaction.Rollback();
            return false;
        }
        finally
        {
            connection.Close();
        }

        return true;
    }

    public int GetPosition_Sector_ID(string pozicia, int odvetvie) 
    {
        command = new OdbcCommand("SELECT id from alumni.pozicia_odvetvie WHERE pozicia = ? AND odvetvie_id = ?", connection);

        command.Parameters.Add("@pozicia", OdbcType.VarChar).Value = pozicia;
        command.Parameters.Add("@odvetvie_id", OdbcType.Int).Value = odvetvie;

        int pozicia_odvetvie_id;

        try
        {
            connection.Open();
            dataReader = command.ExecuteReader();

            if (!dataReader.Read())
            {
                dataReader.Close();
                connection.Close();
                return -1;
            }

            pozicia_odvetvie_id = dataReader.GetInt32(0);
        }
        catch (OdbcException ex)
        {
            throw ex;
        }
        finally
        {
            dataReader.Close();
            connection.Close();
        }

        return pozicia_odvetvie_id;
    }

    public void GetDDLDataSource(string selectionString, System.Web.UI.WebControls.DropDownList ddl)
    {
        command = new OdbcCommand(selectionString, connection);

        try
        {
            connection.Open();
            dataReader = command.ExecuteReader();
            
            ddl.DataSource = dataReader;
            ddl.DataValueField = dataReader.GetName(0);
            ddl.DataTextField = dataReader.GetName(1);
            ddl.DataBind();
        }
        catch (OdbcException ex)
        {
            throw ex;
        }
        finally
        {
            dataReader.Close();
            connection.Close();
        }
    }

    public bool InsertLanguage(int osoba_id, string jazyk, int poroz_pocuvanie, int poroz_citanie,
                                int kom_interakcia, int kom_prejav, int pisanie)
    {
        command = new OdbcCommand("INSERT INTO alumni.jazyk( osoba_id, jazyk, porozumenie_pocuvanie," +
                "porozumenie_citanie, hovorenie_interakcia, hovorenie_prejav, pisanie )" +
                " VALUES ( ?, ?, ?, ?, ?, ?, ? )", connection);

        command.Parameters.Add("@osoba_id", OdbcType.Int).Value = osoba_id;
        command.Parameters.Add("@jazyk", OdbcType.VarChar, 30).Value = jazyk;
        command.Parameters.Add("@porozumenie_pocuvanie", OdbcType.Int).Value = poroz_pocuvanie;
        command.Parameters.Add("@porozumenie_citanie", OdbcType.Int).Value = poroz_citanie;
        command.Parameters.Add("@hovorenie_interakcia", OdbcType.Int).Value = kom_interakcia;
        command.Parameters.Add("@hovorenie_prejav", OdbcType.Int).Value = kom_prejav;
        command.Parameters.Add("@pisanie", OdbcType.Int).Value = pisanie;

        try
        {
            connection.Open();
            command.Transaction = connection.BeginTransaction();
            command.ExecuteNonQuery();
            command.Transaction.Commit();
        }
        catch (OdbcException ex)
        {
            command.Transaction.Rollback();
            return false;
        }
        finally
        {
            connection.Close();
        }

        return true;
    }

    public bool InsertKurz(int osoba_id, string nazov, DateTime datum_od, DateTime datum_do, string pozn)
    {
        command = new OdbcCommand("INSERT INTO alumni.kurz( osoba_id, nazov, datum_od, datum_do, poznamka )" +
                " VALUES ( ?, ?, ?, ?, ? )", connection);

        command.Parameters.Add("@osoba_id", OdbcType.Int).Value = osoba_id;
        command.Parameters.Add("@nazov", OdbcType.VarChar, 100).Value = nazov;
        command.Parameters.Add("@datum_od", OdbcType.Date).Value = datum_od;
        command.Parameters.Add("@datum_do", OdbcType.Date).Value = datum_do;
        command.Parameters.Add("@pozn", OdbcType.Text).Value = pozn;

        try
        {
            connection.Open();
            command.Transaction = connection.BeginTransaction();
            command.ExecuteNonQuery();
            command.Transaction.Commit();
        }
        catch (OdbcException ex)
        {
            command.Transaction.Rollback();
            return false;
        }
        finally
        {
            connection.Close();
        }

        return true;
    }

    public System.Collections.ArrayList SelectFromDatabase(string selectionString) 
    {
        command = new OdbcCommand(selectionString, connection);
        
        //command.Parameters.Add("@id", OdbcType.Int).Value = id;
        //object[] values = new object[dataReader.FieldCount];
        System.Collections.ArrayList al = new System.Collections.ArrayList();
        //dataReader.GetValue();
        //al.AddRange(values);


        try
        {
            connection.Open();
            dataReader = command.ExecuteReader();

            if (!dataReader.Read())
            {
                dataReader.Close();
                connection.Close();
                return null;
            }

            for (int i = 0; i < dataReader.FieldCount; i++)
            {
                al.Add(dataReader.GetValue(i));
            }
        }
        catch (OdbcException ex)
        {
            throw ex;
        }
        finally
        {
            dataReader.Close();
            connection.Close();
        }

        return al;
    }

    public bool DeleteFromDatabase(string deletionString)
    {
        command = new OdbcCommand(deletionString, connection);

        bool deleted = false;

        try
        {
            connection.Open();
            command.Transaction = connection.BeginTransaction();
            if (command.ExecuteNonQuery() > 0) deleted = true;
            command.Transaction.Commit();
        }
        catch (OdbcException ex)
        {
            return false;
        }
        finally
        {
            connection.Close();
        }

        return deleted;
    }
}
