using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

public class ProjectsQueryManager : OdbcQueryManager
{
    public ProjectsQueryManager(string odbcConnectionStringName) : base(odbcConnectionStringName)
    {
    }

    public string GetAbstract(int id)
    {
        command = new OdbcCommand("SELECT alumni.projekt.abstrakt" +
                " FROM alumni.projekt" +
                " WHERE alumni.projekt.id = ?", connection);

        command.Parameters.Add("@alumni.projekt.id", OdbcType.Int).Value = id;
     
        try
        {
            connection.Open();
            return command.ExecuteScalar().ToString();
        }
        catch (OdbcException ex)
        {
            return null;
        }
        finally
        {
            connection.Close();
        }
    }

    public string GetKeyWords(int id)
    {
        command = new OdbcCommand("SELECT alumni.projekt.klucove_slova" +
         " FROM alumni.projekt" +
         " WHERE alumni.projekt.id = ?", connection);

        command.Parameters.Add("@alumni.projekt.id", OdbcType.Int).Value = id;

        try
        {
            connection.Open();
            return command.ExecuteScalar().ToString();
        }
        catch (OdbcException ex)
        {
            return null;
        }
        finally
        {
            connection.Close();
        }
    }

    public string GetNote(int id)
    {
        command = new OdbcCommand("SELECT alumni.projekt.poznamka" +
         " FROM alumni.projekt" +
         " WHERE alumni.projekt.id = ?", connection);

        command.Parameters.Add("@alumni.projekt.id", OdbcType.Int).Value = id;

        try
        {
            connection.Open();
            return command.ExecuteScalar().ToString();
        }
        catch (OdbcException ex)
        {
            return null;
        }
        finally
        {
            connection.Close();
        }
    }

    public bool InsertProject(int id, string caption, string leader, string target, string abstrakt, string keywords, DateTime date, string note)
    {        
        command = new OdbcCommand("INSERT INTO alumni.projekt( osoba_id, nazov, abstrakt, veduci, klucove_slova, datum_vypracovania, www_odkaz, poznamka )" +
                " VALUES ( ?, ?, ?, ?, ?, ?, ?, ? )", connection);
        
        command.Parameters.Add("@osoba_id", OdbcType.Int).Value = id;
        command.Parameters.Add("@nazov", OdbcType.VarChar, 100).Value = caption;
        command.Parameters.Add("@abstrakt", OdbcType.Text).Value = abstrakt;
        command.Parameters.Add("@veduci", OdbcType.VarChar, 50).Value = leader;
        command.Parameters.Add("@klucove_slova", OdbcType.Text).Value = keywords;
        command.Parameters.Add("@datum_vypracovania", OdbcType.DateTime).Value = date;
        command.Parameters.Add("@www_odkaz", OdbcType.Text).Value = target;
        command.Parameters.Add("@poznamka", OdbcType.Text).Value = note;

        try
        {
            connection.Open();

            command.Transaction = connection.BeginTransaction();

            command.ExecuteNonQuery();

            command.Transaction.Commit();
        }
        catch (OdbcException ex)
        {
            command.Transaction.Rollback();
            throw ex;

            return false;
        }
        finally
        {
            connection.Close();
        }

        return true;
    }



    public bool DeleteProject(int id, int idProjektu)
    {
        command = new OdbcCommand( "DELETE FROM alumni.projekt WHERE id = ? AND osoba_id = ?", connection );
        command.Parameters.Add("@id", OdbcType.Int).Value = idProjektu;
        command.Parameters.Add("@osoba_id", OdbcType.Int).Value = id;
        bool deleted = false;

        try
        {
            connection.Open();
            command.Transaction = connection.BeginTransaction();
            if( command.ExecuteNonQuery() > 0 ) deleted = true;
            command.Transaction.Commit();
        }
        catch ( OdbcException ex )
        {
            throw ex;
            return deleted;
        }
        finally
        {
            connection.Close();
        }

        return deleted;
    }
    
}
