﻿using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

public class RegisterQueryManager : OdbcQueryManager
{
    public RegisterQueryManager( string odbcConnectionStringName ) : base( odbcConnectionStringName )
	{
	}

    public bool DeleteRegistration( int registrationId )
    {
        command = new OdbcCommand( "DELETE FROM alumni.registracia WHERE id = ?", connection );

        command.Parameters.Add("@id", OdbcType.Int).Value = registrationId;

        bool deleted = false;

        try
        {
            connection.Open();

            command.Transaction = connection.BeginTransaction();

            if( command.ExecuteNonQuery() > 0 ) deleted = true;

            command.Transaction.Commit();
        }
        catch ( OdbcException ex )
        {
            return false;
        }
        finally
        {
            connection.Close();
        }

        return deleted;
    }

    public string InsertUser( int registrationId, string username, int userType )
    {
        string password;
        string email;
        string firstname;
        string surename;
        DateTime birthday;

        try
        {
            connection.Open();

            command = new OdbcCommand("SELECT heslo, email, meno, priezvisko, datum_narodenia" +
                    " FROM alumni.registracia WHERE id = ?", connection);

            command.Parameters.Add("@id", OdbcType.Int).Value = registrationId;

            int rows = command.ExecuteNonQuery();

            dataReader = command.ExecuteReader();

            if (!dataReader.Read())
            {
                dataReader.Close();
                connection.Close();
                return "Požiadavka o registráciu už neexistuje!";
            }

            password = dataReader.GetString(0);
            email = dataReader.GetString(1);
            firstname = dataReader.GetString(2);
            surename = dataReader.GetString(3);
            birthday = dataReader.GetDate(4);

            dataReader.Close();
        }
        catch ( OdbcException ex )
        {
            return "Požiadavka o registráciu už neexistuje!";
        }
        finally
        {
            connection.Close();
        }

        if ( UserExists( username ) )
        {
            return "Používateľské meno je obsadené!";
        }

        if ( EmailExists( email ) )
        {
            return "Email je už obsadený!";
        }

        try 
        {
            command = new OdbcCommand( "INSERT INTO alumni.osoba( typ_osoby_id, konto, heslo, meno, priezvisko, email, datum_narodenia )" +
                    " VALUES ( ?, ?, ?, ?, ?, ? ,? )", connection );

            command.Parameters.Add("@typ_osoby_id", OdbcType.Int).Value = userType;
            command.Parameters.Add("@konto", OdbcType.VarChar, 20).Value = username.ToLower();
            command.Parameters.Add("@heslo", OdbcType.VarChar, 512).Value = password;
            command.Parameters.Add("@meno", OdbcType.VarChar, 20).Value = firstname;
            command.Parameters.Add("@priezvisko", OdbcType.VarChar, 20).Value = surename;
            command.Parameters.Add("@email", OdbcType.VarChar, 50).Value = ConvertEmail(email);
            command.Parameters.Add("@datum_narodenia", OdbcType.Date).Value = birthday;

            connection.Open();

            command.Transaction = connection.BeginTransaction();

            command.ExecuteNonQuery();

            command.Transaction.Commit();
        }
        catch ( OdbcException ex )
        {
            command.Transaction.Rollback();

            return "Nebolo možné prida používate¾a!";
        }
        finally
        {
            connection.Close();
        }

        return string.Empty;
    }

    public bool InsertRegistration( string password, string email, string firstname, string surename, DateTime birthday, int graduated, int type ) 
    {
        command = new OdbcCommand( "INSERT INTO alumni.registracia( typ_registracie_id, heslo, meno, priezvisko, email, datum_narodenia, rok_absolvovania )" +
                " VALUES ( ?, ?, ?, ?, ?, ?, ? )", connection );

        command.Parameters.Add("@typ_registracie_id", OdbcType.Int).Value = type;
        command.Parameters.Add("@heslo", OdbcType.VarChar, 512).Value = CryptoManager.ComputeHash( password, "SHA512", null );
        command.Parameters.Add("@meno", OdbcType.VarChar, 20).Value = firstname;
        command.Parameters.Add("@priezvisko", OdbcType.VarChar, 20).Value = surename;
        command.Parameters.Add("@email", OdbcType.VarChar, 50).Value = ConvertEmail( email );
        command.Parameters.Add("@datum_narodenia", OdbcType.Date).Value = birthday;
        command.Parameters.Add("@rok_absolvovania", OdbcType.Int).Value = graduated;

        try 
        {
            connection.Open();

            command.Transaction = connection.BeginTransaction();

            command.ExecuteNonQuery();

            command.Transaction.Commit();
        }
         catch ( OdbcException ex )
        {
            command.Transaction.Rollback();

            return false;
        }
        finally
        {
            connection.Close();
        }

        return true;
    }

    public bool RegistrationExists( string email )
    {
        command = new OdbcCommand( "SELECT * FROM alumni.registracia WHERE email = ?", connection );

        command.Parameters.Add("@alumni.osoba.email", OdbcType.VarChar, 20).Value = ConvertEmail( email );

        bool exists = false;

        try
        {
            connection.Open();

            if( command.ExecuteNonQuery() > 0 ) exists = true;
        }
        catch ( OdbcException ex )
        {
            throw ex;
        }
        finally
        {
            connection.Close();
        }

        return exists;
    }

    public string UpdateUser( int registrationId, string username )
    {
        string password;
        string email;

        try
        {
            connection.Open();

            command = new OdbcCommand( "SELECT heslo, email FROM alumni.registracia WHERE id = ?", connection );

            command.Parameters.Add("@id", OdbcType.Int).Value = registrationId;

            int rows = command.ExecuteNonQuery();

            dataReader = command.ExecuteReader();

            if (!dataReader.Read())
            {
                dataReader.Close();
                connection.Close();
                return "Požiadavka o registráciu už neexistuje!";
            }

            password = dataReader.GetString(0);
            email = dataReader.GetString(1);

            dataReader.Close();
        }
        catch ( OdbcException ex )
        {
            return "Požiadavka o registráciu už neexistuje!";
        }
        finally
        {
            connection.Close();
        }

        if ( !UserExists( username ) )
        {
            return "Úèet s týmto používate¾ským menom neexistuje!";
        }

        try 
        {
            command = new OdbcCommand( "UPDATE alumni.osoba SET heslo = ?, email = ? WHERE konto = ?", connection );

            command.Parameters.Add("@password", OdbcType.VarChar, 512).Value = password;
            command.Parameters.Add("@email", OdbcType.VarChar, 512).Value = email;
            command.Parameters.Add("@konto", OdbcType.VarChar, 20).Value = username.ToLower();

            connection.Open();

            command.Transaction = connection.BeginTransaction();

            command.ExecuteNonQuery();

            command.Transaction.Commit();
        }
        catch ( OdbcException ex )
        {
            command.Transaction.Rollback();

            return "Nebolo možné obnovi úèet!";
        }
        finally
        {
            connection.Close();
        }

        return string.Empty;
    }
}
