SET search_path = alumni;
SET default_tablespace = '';
SET default_with_oids = false; 


DROP TABLE IF EXISTS adresa;
DROP TABLE IF EXISTS anketa;
DROP TABLE IF EXISTS jazyk;
DROP TABLE IF EXISTS jazyk_hodnotenie;
DROP TABLE IF EXISTS pracovny_pomer;
DROP TABLE IF EXISTS kurz;
DROP TABLE IF EXISTS mozne_odpovede;
DROP TABLE IF EXISTS obmedzenie;
DROP TABLE IF EXISTS odpoved;
DROP TABLE IF EXISTS odvetvie;
DROP TABLE IF EXISTS obmedzenie;
DROP TABLE IF EXISTS operacia;
DROP TABLE IF EXISTS osoba;
DROP TABLE IF EXISTS otazka;
DROP TABLE IF EXISTS pozicia_odvetvie;
DROP TABLE IF EXISTS prispevok;
DROP TABLE IF EXISTS projekt;
DROP TABLE IF EXISTS registracia;
DROP TABLE IF EXISTS skola;
DROP TABLE IF EXISTS smer;
DROP TABLE IF EXISTS sprava;
DROP TABLE IF EXISTS stat;
DROP TABLE IF EXISTS studium;
DROP TABLE IF EXISTS tema;
DROP TABLE IF EXISTS typ_osoby;
DROP TABLE IF EXISTS typ_registracie;


CREATE TABLE adresa (
    id serial NOT NULL UNIQUE,
    ulica text NOT NULL,
    cislo character varying(10),
    mesto character varying(50) NOT NULL,
    stat_id integer NOT NULL,
    CONSTRAINT adresa_pkey PRIMARY KEY (id)
);

CREATE TABLE anketa (
    id serial NOT NULL UNIQUE,
    nazov character varying(100),
    je_anonymna boolean DEFAULT false NOT NULL,
    je_uzavreta boolean DEFAULT false NOT NULL,
    datum_spustenia timestamp with time zone NOT NULL,
    datum_uzavretia timestamp with time zone,
    CONSTRAINT anketa_pkey PRIMARY KEY (id)
);

CREATE TABLE jazyk (
    id serial NOT NULL UNIQUE,
    osoba_id integer NOT NULL,
    porozumenie_pocuvanie integer DEFAULT 0 NOT NULL,
    porozumenie_citanie integer DEFAULT 0 NOT NULL,
    hovorenie_interakcia integer DEFAULT 0 NOT NULL,
    hovorenie_prejav integer DEFAULT 0 NOT NULL,
    pisanie integer DEFAULT 0 NOT NULL,
    jazyk character varying(30) NOT NULL,
    CONSTRAINT jazyk_pkey PRIMARY KEY (id)
);

CREATE TABLE jazyk_hodnotenie (
    id serial NOT NULL UNIQUE,
    hodnotenie_skupina character(2) NOT NULL,
    hodnotenie_popis text,
    CONSTRAINT jazyk_hodnotenie_pkey PRIMARY KEY (id)
);

CREATE TABLE pracovny_pomer (
    id serial NOT NULL UNIQUE,
    osoba_id integer NOT NULL,
    pozicia_odvetvie_id integer,
    datum_od date NOT NULL,
    datum_do date,
    nazov_firmy character varying(50) NOT NULL,
    poznamka text,
    adresa_id integer,
    CONSTRAINT pracovny_pomer_pkey PRIMARY KEY (id)
);

CREATE TABLE kurz (
    id serial NOT NULL UNIQUE,
    nazov character varying(100) NOT NULL,
    datum_od date,
    datum_do date,
    poznamka text,
    osoba_id integer NOT NULL,
    CONSTRAINT kurz_pkey PRIMARY KEY (id)
);

CREATE TABLE mozne_odpovede (
    id serial NOT NULL UNIQUE,
    text text,
    ine boolean DEFAULT false NOT NULL,
    otazka_id integer NOT NULL,
    CONSTRAINT mozne_odpovede_pkey PRIMARY KEY (id)
);

CREATE TABLE obmedzenie (
    typ_osoby_id integer NOT NULL,
    operacia_id integer NOT NULL,
    objekt_obmedzenia integer NOT NULL
);

CREATE TABLE odpoved (
    id serial NOT NULL UNIQUE,
    odpoved text,
    osoba_id integer,
    otazka_id integer NOT NULL,
    CONSTRAINT odpoved_pkey PRIMARY KEY (id)
);

CREATE TABLE odvetvie (
    id serial NOT NULL UNIQUE,
    odvetvie character varying(50) NOT NULL,
    CONSTRAINT odvetvie_pkey PRIMARY KEY (id)
);

CREATE TABLE operacia (
    id serial NOT NULL UNIQUE,
    operacia character varying(20) NOT NULL,
    CONSTRAINT operacia_pkey PRIMARY KEY (id)
);

CREATE TABLE osoba (
    id serial NOT NULL UNIQUE,
    adresa_id integer,
    typ_osoby_id integer NOT NULL,
    konto character varying(20) NOT NULL,
    konto_aktivne boolean DEFAULT true NOT NULL,
    heslo character varying(512) NOT NULL,
    posledne_prihlasenie timestamp DEFAULT now() NOT NULL,
    posledna_ip inet,
    meno character varying(20) NOT NULL,
    titul_pred character varying(10),
    titul_za character varying(10),
    priezvisko character varying(20) NOT NULL,
    rodne_priezvisko character varying(25),
    statna_prislusnost character varying(30),
    materinsky_jazyk character varying(30),
    telefon character varying(20),
    email character varying(50) NOT NULL,
    web text,
    pohlavie character varying(4),
    datum_narodenia date NOT NULL,
    cv_ine text,
    icq numeric(15,0),
    skype text,
    fotografia bytea,
    CONSTRAINT osoba_pkey PRIMARY KEY (id)
);

CREATE TABLE otazka (
    id serial NOT NULL UNIQUE,
    otazka text NOT NULL,
    typ_odpovede smallint NOT NULL,
    anketa_id integer NOT NULL,
    CONSTRAINT otazka_pkey PRIMARY KEY (id)
);

CREATE TABLE pozicia_odvetvie (
    id serial NOT NULL UNIQUE,
    pozicia character varying(50) NOT NULL,
    odvetvie_id integer DEFAULT 0 NOT NULL,
    CONSTRAINT pozicia_odvetvie_pkey PRIMARY KEY (id)
);

CREATE TABLE prispevok (
    text text NOT NULL,
    cas timestamp with time zone NOT NULL,
    tema_id integer NOT NULL,
    osoba_id integer NOT NULL,
    id integer NOT NULL,
    predmet character varying(100)
);

CREATE TABLE projekt (
    id serial NOT NULL UNIQUE,
    osoba_id integer NOT NULL,
    job_id integer,
    studium_id integer,
    nazov character varying(100) NOT NULL,
    abstrakt text,
    veduci character varying(50),
    klucove_slova text NOT NULL,
    datum_vypracovania date NOT NULL,
    www_odkaz text,
    poznamka text,
    CONSTRAINT projekt_pkey PRIMARY KEY (id)
);

CREATE TABLE registracia (
    id serial NOT NULL UNIQUE,
    email character varying(50) NOT NULL UNIQUE,
    heslo character varying(512) NOT NULL,
    meno character varying(20) NOT NULL,
    priezvisko character varying(20) NOT NULL,
    datum_narodenia date NOT NULL,
    rok_absolvovania integer,
    CONSTRAINT registracia_pkey PRIMARY KEY (id)
);

CREATE TABLE skola (
    id serial NOT NULL UNIQUE,
    nazov character varying(255) NOT NULL,
    CONSTRAINT skola_pkey PRIMARY KEY (id)
);

CREATE TABLE smer (
    id serial NOT NULL UNIQUE,
    smer character varying(50) NOT NULL,
    CONSTRAINT smer_pkey PRIMARY KEY (id)
);

CREATE TABLE sprava (
    id serial NOT NULL UNIQUE,
    odosielatel_id integer NOT NULL,
    prijemca_id integer NOT NULL,
    cas timestamp with time zone NOT NULL,
    predmet character varying(100),
    text text,
    priecinok numeric(1,0) NOT NULL,
    precitana boolean DEFAULT false NOT NULL,
    kos boolean DEFAULT false NOT NULL,
    CONSTRAINT sprava_pkey PRIMARY KEY (id)
);

CREATE TABLE stat (
    id serial NOT NULL UNIQUE,
    stat character varying(50) NOT NULL,
    CONSTRAINT stat_pkey PRIMARY KEY (id)
);

CREATE TABLE studium (
    id serial NOT NULL UNIQUE,
    osoba_id integer NOT NULL,
    skola_id integer NOT NULL,
    smer_id integer,
    stupen numeric(1,0) DEFAULT 1 NOT NULL,
    osobne_cislo numeric(15,0),
    datum_od date,
    datum_do date,
    prospech numeric(2,2),
    fakulta character varying(100),
    odbor character varying(50),
    typ_skoly numeric(2,0),
    prebieha boolean DEFAULT false NOT NULL,
    CONSTRAINT studium_pkey PRIMARY KEY (id)
);

CREATE TABLE tema (
    id serial NOT NULL UNIQUE,
    nazov character varying(100) NOT NULL,
    popis text,
    cas timestamp with time zone NOT NULL,
    je_verejna boolean DEFAULT true NOT NULL,
    osoba_id integer NOT NULL,
    nadtema integer,
    CONSTRAINT tema_pkey PRIMARY KEY (id)
);

CREATE TABLE typ_osoby (
    id serial NOT NULL UNIQUE,
    typ character varying(30) NOT NULL,
    CONSTRAINT typ_osoby_pkey PRIMARY KEY (id)
);

CREATE TABLE typ_registracie (
    id serial NOT NULL UNIQUE,
    typ character varying(30) NOT NULL,
    CONSTRAINT typ_registracie_pkey PRIMARY KEY (id)
);


INSERT INTO osoba(
            typ_osoby_id, konto, konto_aktivne, heslo, posledne_prihlasenie, 
            posledna_ip, meno, priezvisko, telefon, email, web, pohlavie, 
            datum_narodenia )
     VALUES ( 4, 'admin', true, 'Pp+OaSS0MPzhKJ4i6oJ4ROEt6zynmHNEZ1/X1QNVqnrCV7AnG0El+vbLYC2xPmeg9YK7qqRLHy95PTw9tInmflPa6/sp8IKldkgyXyz2/yA=', now(), '127.0.0.1', 
            'Admin', 'Admin', '123456789', 'noxi@pobox.sk', 'www.mojweb.sk', 'muz', '01-Jan-2000' );

INSERT INTO typ_osoby(typ) VALUES ('tudent');
INSERT INTO typ_osoby(typ) VALUES ('Absolvent');
INSERT INTO typ_osoby(typ) VALUES ('Fakultnk');
INSERT INTO typ_osoby(typ) VALUES ('Administrtor');

INSERT INTO typ_registracie(typ) VALUES ('Nov registrcia');
INSERT INTO typ_registracie(typ) VALUES ('Obnovenie tu');